@@ -31,8 +31,8 @@ def _api_encode(data) -> Generator[Tuple[str, Any], None, None]:
     for key, value in data.items():
         if value is None:
             continue
-        elif hasattr(value, "stripe_id"):
-            yield (key, value.stripe_id)
+        elif hasattr(value, "id"):
+            yield (key, getattr(value, "id"))
         elif isinstance(value, list) or isinstance(value, tuple):
             for i, sv in enumerate(value):
                 # Always use indexed format for arrays
